{% ckan_extends %}

{% block skip %}
    {% if h.status_get_message() %}
        {% asset 'ckanext-status/main' %}
        <div id="status-bar">
            {% if h.status_enable_html() %}
                {{ h.status_get_message()|safe }}
            {% else %}
                {{ h.status_get_message() }}
            {% endif %}
        </div>
    {% endif %}
    {{ super() }}
{% endblock %}
